package #
Devel::AssertOS::Alias::MacOS;

use strict;
use warnings;

use Devel::CheckOS;

our $VERSION = '1.0';

Devel::CheckOS::register_alias(MacOS => 'MacOSX');

=head1 COPYRIGHT and LICENCE

Copyright 2024 David Cantrell

This software is free-as-in-speech software, and may be used, distributed, and modified under the terms of either the GNU General Public Licence version 2 or the Artistic Licence. It's up to you which one you use. The full text of the licences can be found in the files GPL2.txt and ARTISTIC.txt, respectively.

=cut

1;
